"""Views for the admin_keyboard_shortcuts app."""
# from django.views.generic import TemplateView

# from . import models


# class YourView(TemplateView):
#    template_name = 'admin_keyboard_shortcuts/default.html'



from django import template
from django.conf import settings


register = template.Library()


@register.filter
def display_cmd_key_icon(dummy):
    if hasattr(settings, 'ADMIN_KEYBOARD_SHORTCUTS_HIDE_ICON') and settings.ADMIN_KEYBOARD_SHORTCUTS_HIDE_ICON:
        return False
    return True
